.. image:: https://img.shields.io/pypi/v/soral-data-test.svg?color=blue
   :alt: PyPI-Server
   :target: https://pypi.org/project/soral-data-test/

====================================
X-I-A
====================================



Quick start
=============================

Install the package::

    pip install


